@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_iam._jsii
@@ -18,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-dynamodb-stream-lambda",
-    "1.57.0",
+    "1.63.0",
     __name__[0:-6],
-    "aws-dynamodb-stream-lambda@1.57.0.jsii.tgz",
+    "aws-dynamodb-stream-lambda@1.63.0.jsii.tgz",
 )
 
 __all__ = [
